@@ -35,6 +35,7 @@ from mypy_boto3_cloudwatch.type_defs import (
     DescribeAlarmsOutputTypeDef,
     DimensionFilterTypeDef,
     GetMetricDataOutputTypeDef,
+    LabelOptionsTypeDef,
     ListDashboardsOutputTypeDef,
     ListMetricsOutputTypeDef,
     MetricDataQueryTypeDef,
@@ -58,7 +59,7 @@ __all__ = (
 
 class DescribeAlarmHistoryPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeAlarmHistory documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.57/reference/services/cloudwatch.html#CloudWatch.Paginator.DescribeAlarmHistory)
+    [Paginator.DescribeAlarmHistory documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.0/reference/services/cloudwatch.html#CloudWatch.Paginator.DescribeAlarmHistory)
     """
 
     def paginate(
@@ -72,13 +73,13 @@ class DescribeAlarmHistoryPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[DescribeAlarmHistoryOutputTypeDef]:
         """
-        [DescribeAlarmHistory.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.57/reference/services/cloudwatch.html#CloudWatch.Paginator.DescribeAlarmHistory.paginate)
+        [DescribeAlarmHistory.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.0/reference/services/cloudwatch.html#CloudWatch.Paginator.DescribeAlarmHistory.paginate)
         """
 
 
 class DescribeAlarmsPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeAlarms documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.57/reference/services/cloudwatch.html#CloudWatch.Paginator.DescribeAlarms)
+    [Paginator.DescribeAlarms documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.0/reference/services/cloudwatch.html#CloudWatch.Paginator.DescribeAlarms)
     """
 
     def paginate(
@@ -93,13 +94,13 @@ class DescribeAlarmsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[DescribeAlarmsOutputTypeDef]:
         """
-        [DescribeAlarms.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.57/reference/services/cloudwatch.html#CloudWatch.Paginator.DescribeAlarms.paginate)
+        [DescribeAlarms.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.0/reference/services/cloudwatch.html#CloudWatch.Paginator.DescribeAlarms.paginate)
         """
 
 
 class GetMetricDataPaginator(Boto3Paginator):
     """
-    [Paginator.GetMetricData documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.57/reference/services/cloudwatch.html#CloudWatch.Paginator.GetMetricData)
+    [Paginator.GetMetricData documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.0/reference/services/cloudwatch.html#CloudWatch.Paginator.GetMetricData)
     """
 
     def paginate(
@@ -108,29 +109,30 @@ class GetMetricDataPaginator(Boto3Paginator):
         StartTime: datetime,
         EndTime: datetime,
         ScanBy: Literal["TimestampDescending", "TimestampAscending"] = None,
+        LabelOptions: LabelOptionsTypeDef = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[GetMetricDataOutputTypeDef]:
         """
-        [GetMetricData.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.57/reference/services/cloudwatch.html#CloudWatch.Paginator.GetMetricData.paginate)
+        [GetMetricData.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.0/reference/services/cloudwatch.html#CloudWatch.Paginator.GetMetricData.paginate)
         """
 
 
 class ListDashboardsPaginator(Boto3Paginator):
     """
-    [Paginator.ListDashboards documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.57/reference/services/cloudwatch.html#CloudWatch.Paginator.ListDashboards)
+    [Paginator.ListDashboards documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.0/reference/services/cloudwatch.html#CloudWatch.Paginator.ListDashboards)
     """
 
     def paginate(
         self, DashboardNamePrefix: str = None, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListDashboardsOutputTypeDef]:
         """
-        [ListDashboards.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.57/reference/services/cloudwatch.html#CloudWatch.Paginator.ListDashboards.paginate)
+        [ListDashboards.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.0/reference/services/cloudwatch.html#CloudWatch.Paginator.ListDashboards.paginate)
         """
 
 
 class ListMetricsPaginator(Boto3Paginator):
     """
-    [Paginator.ListMetrics documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.57/reference/services/cloudwatch.html#CloudWatch.Paginator.ListMetrics)
+    [Paginator.ListMetrics documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.0/reference/services/cloudwatch.html#CloudWatch.Paginator.ListMetrics)
     """
 
     def paginate(
@@ -142,5 +144,5 @@ class ListMetricsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListMetricsOutputTypeDef]:
         """
-        [ListMetrics.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.57/reference/services/cloudwatch.html#CloudWatch.Paginator.ListMetrics.paginate)
+        [ListMetrics.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.0/reference/services/cloudwatch.html#CloudWatch.Paginator.ListMetrics.paginate)
         """
